@@ -51,7 +51,7 @@ class IMobilethemeTwoSettings(form.Schema):
     )
                   
     scrape_url = schema.URI(
-                title='scrape_url',
+                title=_(u"scrape_url", default=u"Default URL"),
     )
                       
     scrape_javascript = schema.Bool(
